@@ -22,7 +22,7 @@ from .custom_context import Context
 from .database import DatabaseConnection
 from .redis import RedisConnection
 from .statsd import StatsdConnection
-from .analytics_log_handler import AnalyticsLogHandler
+from .analytics_log_handler import AnalyticsLogHandler, AnalyticsClientSession
 from .interactions.components import MessageComponents
 from .models import ComponentMessage, ComponentWebhookMessage
 from .shard_manager import ShardManagerClient
@@ -550,7 +550,7 @@ class MinimalBot(commands.AutoShardedBot):
                 for f in files:
                     f.close()
         else:
-            if wait is False and messageable._sent_ack_response is False:
+            if isinstance(channel, (list, tuple)) and wait is False and messageable._sent_ack_response is False:
                 payload = {"type": _no_wait_response_type, "data": payload.copy()}
             response_data = await messageable._state.http.request(r, json=payload)
 
@@ -565,6 +565,7 @@ class MinimalBot(commands.AutoShardedBot):
             pass
 
         # See if we want to respond with anything
+        lock.release()
         if wait is False:
             return
 
@@ -579,7 +580,6 @@ class MinimalBot(commands.AutoShardedBot):
             ret = ComponentMessage(state=state, channel=channel, data=response_data)
 
         # See if we want to delete the message
-        lock.release()
         if delete_after is not None:
             await ret.delete(delay=delete_after)
 
@@ -786,7 +786,7 @@ class Bot(MinimalBot):
         }
 
         # Aiohttp session
-        self.session: aiohttp.ClientSession = aiohttp.ClientSession(loop=self.loop)
+        self.session: aiohttp.ClientSession = AnalyticsClientSession(self, loop=self.loop, headers={"User-Agent": self.user_agent})
 
         # Allow database connections like this
         self.database: DatabaseConnection = DatabaseConnection
@@ -994,6 +994,7 @@ class Bot(MinimalBot):
         self._upgrade_chat = upgradechat.UpgradeChat(
             self.config["upgrade_chat"]["client_id"],
             self.config["upgrade_chat"]["client_secret"],
+            session=self.session,
         )
         return self._upgrade_chat
 
