@@ -1,4 +1,4 @@
 from .application_commands import (
     ApplicationCommandOptionType, ApplicationCommandOptionChoice, ApplicationCommandOption,
-    ApplicationCommand, InteractionMessage,
+    ApplicationCommand, InteractionMessage, ApplicationCommandType
 )
